@@ -307,7 +307,7 @@ formatting = {
             },
         pyatspi.ROLE_PANEL: {
             'focused': 'labelAndName + roleName',
-            'unfocused': '((substring and currentLineText) or labelAndName) + roleName'
+            'unfocused': '((substring and currentLineText) or labelAndName) + roleName + pause + unrelatedLabels'
             },
         pyatspi.ROLE_PARAGRAPH: {
             'focused': 'labelOrName + readOnly + textRole + textIndentation + currentLineText + allTextSelection',
@@ -332,8 +332,8 @@ formatting = {
             },
         pyatspi.ROLE_RADIO_BUTTON: {
             'focused': 'radioState',
-            'unfocused': 'labelOrName + pause + radioState + roleName + availability + lineBreak + ' + MNEMONIC + ' + accelerator + pause + positionInList + pause',
-            'basicWhereAmI': 'radioButtonGroup + pause + labelOrName + roleName + pause + radioState + pause + positionInGroup + ' + MNEMONIC + ' + accelerator'
+            'unfocused': '(name or label) + pause + radioState + roleName + availability + lineBreak + ' + MNEMONIC + ' + accelerator + pause + positionInList + pause',
+            'basicWhereAmI': 'radioButtonGroup + pause + (name or label) + roleName + pause + radioState + pause + positionInGroup + ' + MNEMONIC + ' + accelerator'
             },
         pyatspi.ROLE_RADIO_MENU_ITEM: {
             # OpenOffice check menu items currently have a role of "menu item"
@@ -414,8 +414,8 @@ formatting = {
             'unfocused': 'labelOrName + roleName + availability '
             },
         pyatspi.ROLE_TERMINAL: {
-            'focused': 'terminal',
-            'unfocused': 'terminal',
+            'focused': 'textContent',
+            'unfocused': 'textContent',
             'basicWhereAmI': 'label + readOnly + pause + textRole + pause + textContent + anyTextSelection + ' + MNEMONIC,
             'detailedWhereAmI': 'label + readOnly + pause + textRole + pause + textContentWithAttributes + anyTextSelection + ' + MNEMONIC
             },
@@ -901,23 +901,28 @@ class Formatting(dict):
           'focused', 'basicWhereAmI', etc.
         """
         try:
-            # First try to find the exact match.
-            #
-            format = self[args['mode']][args['role']][args['formatType']]
+            return self[args['mode']][args['role']][args['formatType']]
         except:
+            pass
+
+        if args.get('formatType') == 'detailedWhereAmI':
             try:
-                # Failing that, fallback to the 'unfocused' formatType
-                # for the mode and role, if it exists.
-                #
-                format = self[args['mode']][args['role']]['unfocused']
+                return self[args['mode']][args['role']]['basicWhereAmI']
             except:
-                try:
-                    # Failing that, fallback to the default for the
-                    # formatType
-                    #
-                    format = self[args['mode']]['default'][args['formatType']]
-                except:
-                    # Failing that, just used the default 'unfocused' format
-                    #
-                    format = self[args['mode']]['default']['unfocused']
-        return format
+                pass
+
+        try:
+            return self[args['mode']][args['role']]['unfocused']
+        except:
+            pass
+
+
+        try:
+            return self[args['mode']]['default'][args['formatType']]
+        except:
+            pass
+
+        try:
+            return self[args['mode']]['default']['unfocused']
+        except:
+            return []
