@@ -166,7 +166,7 @@ class Script(default.Script):
 
         # Unfiled. When a canvas item gets focus but is not selected, we
         # are only getting a focus event. This happens in Nautilus.
-        if role == pyatspi.ROLE_CANVAS:
+        if role == pyatspi.ROLE_CANVAS and not self.utilities.eventIsCanvasNoise(event):
             orca.setLocusOfFocus(event, event.source)
             return
 
@@ -198,11 +198,16 @@ class Script(default.Script):
     def onSelectionChanged(self, event):
         """Callback for object:selection-changed accessibility events."""
 
-        if event.source.getRole() == pyatspi.ROLE_COMBO_BOX \
+        role = event.source.getRole()
+        if role == pyatspi.ROLE_COMBO_BOX \
            and not event.source.getState().contains(pyatspi.STATE_FOCUSED):
             return
 
-        default.Script.onSelectionChanged(self, event)
+        if role == pyatspi.ROLE_LAYERED_PANE \
+           and self.utilities.selectedChildCount(event.source) > 1:
+            return
+
+        super().onSelectionChanged(event)
 
     def onShowingChanged(self, event):
         """Callback for object:state-changed:showing accessibility events."""
@@ -212,7 +217,7 @@ class Script(default.Script):
             return
 
         obj = event.source
-        if self.utilities._isNonModalPopOver(obj) \
+        if self.utilities.isPopOver(obj) \
            or obj.getRole() in [pyatspi.ROLE_ALERT, pyatspi.ROLE_INFO_BAR]:
             if obj.parent and obj.parent.getRole() == pyatspi.ROLE_APPLICATION:
                 return
@@ -229,3 +234,9 @@ class Script(default.Script):
             return
 
         default.Script.onTextSelectionChanged(self, event)
+
+    def isActivatableEvent(self, event):
+        if self.utilities.eventIsCanvasNoise(event):
+            return False
+
+        return super().isActivatableEvent(event)
