@@ -962,8 +962,8 @@ class Script(default.Script):
         self._focusModeIsSticky = True
 
     def togglePresentationMode(self, inputEvent):
+        [obj, characterOffset] = self.utilities.getCaretContext()
         if self._inFocusMode:
-            [obj, characterOffset] = self.utilities.getCaretContext()
             try:
                 parentRole = obj.parent.getRole()
             except:
@@ -975,6 +975,12 @@ class Script(default.Script):
 
             self.presentMessage(messages.MODE_BROWSE)
         else:
+            if not self.utilities.grabFocusWhenSettingCaret(obj) \
+               and (self._lastCommandWasCaretNav \
+                    or self._lastCommandWasStructNav \
+                    or inputEvent):
+                self.utilities.grabFocus(obj)
+
             self.presentMessage(messages.MODE_FOCUS)
         self._inFocusMode = not self._inFocusMode
         self._focusModeIsSticky = False
@@ -1084,6 +1090,8 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return False
 
+        self.structuralNavigation.clearCache()
+
         if self.utilities.getDocumentForObject(event.source.parent):
             msg = "WEB: Ignoring: Event source is nested document"
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -1206,10 +1214,15 @@ class Script(default.Script):
             self.utilities.setCaretContext(event.source, event.detail1)
             return True
 
-        if self.utilities.inFindToolbar() and not self._madeFindAnnouncement:
-            msg = "WEB: Event handled: Presenting find results"
-            debug.println(debug.LEVEL_INFO, msg, True)
-            self.presentFindResults(event.source, event.detail1)
+        if self.utilities.inFindToolbar():
+            if not self._madeFindAnnouncement:
+                msg = "WEB: Event handled: Presenting find results"
+                debug.println(debug.LEVEL_INFO, msg, True)
+                self.presentFindResults(event.source, event.detail1)
+            else:
+                self.utilities.setCaretContext(event.source, event.detail1)
+                msg = "WEB: Event handled: Setting context to source and offset"
+                debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
         if self.utilities.eventIsAutocompleteNoise(event):
@@ -1245,6 +1258,14 @@ class Script(default.Script):
             self.utilities.setCaretContext(obj, offset)
             return True
 
+        if self.utilities.isContentEditableWithEmbeddedObjects(event.source):
+            msg = "WEB: In content editable with embedded objects"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            notify = orca_state.locusOfFocus == orca_state.activeWindow
+            orca.setLocusOfFocus(event, event.source, notify)
+            self.utilities.setCaretContext(obj, offset)
+            return False
+
         text = self.utilities.queryNonEmptyText(event.source)
         if not text:
             if event.source.getRole() == pyatspi.ROLE_LINK:
@@ -1656,6 +1677,16 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
+        obj, offset = self.utilities.getCaretContext(getZombieReplicant=False)
+        if self.utilities.isZombie(obj):
+            obj, offset = self.utilities.getCaretContext(getZombieReplicant=True)
+            if obj:
+                orca.setLocusOfFocus(event, obj, notifyScript=False)
+
+        if self.utilities.isZombie(obj):
+            msg = "WEB: Unable to get non-null, non-zombie context object"
+            debug.println(debug.LEVEL_INFO, msg, True)
+
         msg = "WEB: Clearing content cache due to text deletion"
         debug.println(debug.LEVEL_INFO, msg, True)
         self.utilities.clearContentCache()
@@ -1782,9 +1813,15 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
+        if self.utilities.isContentEditableWithEmbeddedObjects(event.source):
+            msg = "WEB: In content editable with embedded objects"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return False
+
         char = text.getText(event.detail1, event.detail1+1)
         if char == self.EMBEDDED_OBJECT_CHARACTER \
-           and not self.utilities.lastInputEventWasCaretNavWithSelection():
+           and not self.utilities.lastInputEventWasCaretNavWithSelection() \
+           and not self.utilities.lastInputEventWasCommand():
             msg = "WEB: Ignoring: Not selecting and event offset is at embedded object"
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
